---
name: "\U0001F4DA Documentation"
about: Report an issue with the nc-time-axis documentation
title: ''
labels: 'New: Documentation, Type: Documentation'
assignees: ''

---

## 📚 Documentation
<!-- Describe the issue or provide a suggestion for improving the nc-time-axis documentation -->
